Class: Google::Apis::StorageV1::AnywhereCache
- Inherits:
-
Object
- Object
- Google::Apis::StorageV1::AnywhereCache
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb
Overview
An Anywhere Cache instance.
Instance Attribute Summary collapse
-
#admission_policy ⇒ String
The cache-level entry admission policy.
-
#anywhere_cache_id ⇒ String
The ID of the Anywhere cache instance.
-
#bucket ⇒ String
The name of the bucket containing this cache instance.
-
#create_time ⇒ DateTime
The creation time of the cache instance in RFC 3339 format.
-
#id ⇒ String
The ID of the resource, including the project number, bucket name and anywhere cache ID.
-
#ingest_on_write ⇒ Boolean
(also: #ingest_on_write?)
Specifies whether objects are ingested into the cache upon write.
-
#kind ⇒ String
The kind of item this is.
-
#pending_update ⇒ Boolean
(also: #pending_update?)
True if the cache instance has an active Update long-running operation.
-
#self_link ⇒ String
The link to this cache instance.
-
#state ⇒ String
The current state of the cache instance.
-
#ttl ⇒ String
The TTL of all cache entries in whole seconds.
-
#update_time ⇒ DateTime
The modification time of the cache instance metadata in RFC 3339 format.
-
#zone ⇒ String
The zone in which the cache instance is running.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AnywhereCache
constructor
A new instance of AnywhereCache.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AnywhereCache
Returns a new instance of AnywhereCache.
126 127 128 |
# File 'lib/google/apis/storage_v1/classes.rb', line 126 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admission_policy ⇒ String
The cache-level entry admission policy.
Corresponds to the JSON property admissionPolicy
60 61 62 |
# File 'lib/google/apis/storage_v1/classes.rb', line 60 def admission_policy @admission_policy end |
#anywhere_cache_id ⇒ String
The ID of the Anywhere cache instance.
Corresponds to the JSON property anywhereCacheId
65 66 67 |
# File 'lib/google/apis/storage_v1/classes.rb', line 65 def anywhere_cache_id @anywhere_cache_id end |
#bucket ⇒ String
The name of the bucket containing this cache instance.
Corresponds to the JSON property bucket
70 71 72 |
# File 'lib/google/apis/storage_v1/classes.rb', line 70 def bucket @bucket end |
#create_time ⇒ DateTime
The creation time of the cache instance in RFC 3339 format.
Corresponds to the JSON property createTime
75 76 77 |
# File 'lib/google/apis/storage_v1/classes.rb', line 75 def create_time @create_time end |
#id ⇒ String
The ID of the resource, including the project number, bucket name and anywhere
cache ID.
Corresponds to the JSON property id
81 82 83 |
# File 'lib/google/apis/storage_v1/classes.rb', line 81 def id @id end |
#ingest_on_write ⇒ Boolean Also known as: ingest_on_write?
Specifies whether objects are ingested into the cache upon write.
Corresponds to the JSON property ingestOnWrite
86 87 88 |
# File 'lib/google/apis/storage_v1/classes.rb', line 86 def ingest_on_write @ingest_on_write end |
#kind ⇒ String
The kind of item this is. For Anywhere Cache, this is always storage#
anywhereCache.
Corresponds to the JSON property kind
93 94 95 |
# File 'lib/google/apis/storage_v1/classes.rb', line 93 def kind @kind end |
#pending_update ⇒ Boolean Also known as: pending_update?
True if the cache instance has an active Update long-running operation.
Corresponds to the JSON property pendingUpdate
98 99 100 |
# File 'lib/google/apis/storage_v1/classes.rb', line 98 def pending_update @pending_update end |
#self_link ⇒ String
The link to this cache instance.
Corresponds to the JSON property selfLink
104 105 106 |
# File 'lib/google/apis/storage_v1/classes.rb', line 104 def self_link @self_link end |
#state ⇒ String
The current state of the cache instance.
Corresponds to the JSON property state
109 110 111 |
# File 'lib/google/apis/storage_v1/classes.rb', line 109 def state @state end |
#ttl ⇒ String
The TTL of all cache entries in whole seconds. e.g., "7200s".
Corresponds to the JSON property ttl
114 115 116 |
# File 'lib/google/apis/storage_v1/classes.rb', line 114 def ttl @ttl end |
#update_time ⇒ DateTime
The modification time of the cache instance metadata in RFC 3339 format.
Corresponds to the JSON property updateTime
119 120 121 |
# File 'lib/google/apis/storage_v1/classes.rb', line 119 def update_time @update_time end |
#zone ⇒ String
The zone in which the cache instance is running. For example, us-central1-a.
Corresponds to the JSON property zone
124 125 126 |
# File 'lib/google/apis/storage_v1/classes.rb', line 124 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/google/apis/storage_v1/classes.rb', line 131 def update!(**args) @admission_policy = args[:admission_policy] if args.key?(:admission_policy) @anywhere_cache_id = args[:anywhere_cache_id] if args.key?(:anywhere_cache_id) @bucket = args[:bucket] if args.key?(:bucket) @create_time = args[:create_time] if args.key?(:create_time) @id = args[:id] if args.key?(:id) @ingest_on_write = args[:ingest_on_write] if args.key?(:ingest_on_write) @kind = args[:kind] if args.key?(:kind) @pending_update = args[:pending_update] if args.key?(:pending_update) @self_link = args[:self_link] if args.key?(:self_link) @state = args[:state] if args.key?(:state) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) @zone = args[:zone] if args.key?(:zone) end |