Class: Google::Apis::StorageV1::Bucket::IamConfiguration::BucketPolicyOnly
- Inherits:
-
Object
- Object
- Google::Apis::StorageV1::Bucket::IamConfiguration::BucketPolicyOnly
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb
Overview
The bucket's uniform bucket-level access configuration. The feature was formerly known as Bucket Policy Only. For backward compatibility, this field will be populated with identical information as the uniformBucketLevelAccess field. We recommend using the uniformBucketLevelAccess field to enable and disable the feature.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
If set, access is controlled only by bucket-level or above IAM policies.
-
#locked_time ⇒ DateTime
The deadline for changing iamConfiguration.bucketPolicyOnly.enabled from true to false in RFC 3339 format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BucketPolicyOnly
constructor
A new instance of BucketPolicyOnly.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BucketPolicyOnly
Returns a new instance of BucketPolicyOnly.
796 797 798 |
# File 'lib/google/apis/storage_v1/classes.rb', line 796 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
If set, access is controlled only by bucket-level or above IAM policies.
Corresponds to the JSON property enabled
785 786 787 |
# File 'lib/google/apis/storage_v1/classes.rb', line 785 def enabled @enabled end |
#locked_time ⇒ DateTime
The deadline for changing iamConfiguration.bucketPolicyOnly.enabled from true
to false in RFC 3339 format. iamConfiguration.bucketPolicyOnly.enabled may be
changed from true to false until the locked time, after which the field is
immutable.
Corresponds to the JSON property lockedTime
794 795 796 |
# File 'lib/google/apis/storage_v1/classes.rb', line 794 def locked_time @locked_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
801 802 803 804 |
# File 'lib/google/apis/storage_v1/classes.rb', line 801 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @locked_time = args[:locked_time] if args.key?(:locked_time) end |