Class: Google::Apis::StorageV1::Bucket::IamConfiguration::UniformBucketLevelAccess

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

The bucket's uniform bucket-level access configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UniformBucketLevelAccess

Returns a new instance of UniformBucketLevelAccess.



825
826
827
# File 'lib/google/apis/storage_v1/classes.rb', line 825

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

If set, access is controlled only by bucket-level or above IAM policies. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


814
815
816
# File 'lib/google/apis/storage_v1/classes.rb', line 814

def enabled
  @enabled
end

#locked_timeDateTime

The deadline for changing iamConfiguration.uniformBucketLevelAccess.enabled from true to false in RFC 3339 format. iamConfiguration. uniformBucketLevelAccess.enabled may be changed from true to false until the locked time, after which the field is immutable. Corresponds to the JSON property lockedTime

Returns:

  • (DateTime)


823
824
825
# File 'lib/google/apis/storage_v1/classes.rb', line 823

def locked_time
  @locked_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



830
831
832
833
# File 'lib/google/apis/storage_v1/classes.rb', line 830

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @locked_time = args[:locked_time] if args.key?(:locked_time)
end