Class: Google::Apis::StorageV1::BucketAccessControl

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

An access-control entry.

Defined Under Namespace

Classes: ProjectTeam

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BucketAccessControl

Returns a new instance of BucketAccessControl.



1382
1383
1384
# File 'lib/google/apis/storage_v1/classes.rb', line 1382

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucketString

The name of the bucket. Corresponds to the JSON property bucket

Returns:

  • (String)


1317
1318
1319
# File 'lib/google/apis/storage_v1/classes.rb', line 1317

def bucket
  @bucket
end

#domainString

The domain associated with the entity, if any. Corresponds to the JSON property domain

Returns:

  • (String)


1322
1323
1324
# File 'lib/google/apis/storage_v1/classes.rb', line 1322

def domain
  @domain
end

#emailString

The email address associated with the entity, if any. Corresponds to the JSON property email

Returns:

  • (String)


1327
1328
1329
# File 'lib/google/apis/storage_v1/classes.rb', line 1327

def email
  @email
end

#entityString

The entity holding the permission, in one of the following forms:

Returns:

  • (String)


1344
1345
1346
# File 'lib/google/apis/storage_v1/classes.rb', line 1344

def entity
  @entity
end

#entity_idString

The ID for the entity, if any. Corresponds to the JSON property entityId

Returns:

  • (String)


1349
1350
1351
# File 'lib/google/apis/storage_v1/classes.rb', line 1349

def entity_id
  @entity_id
end

#etagString

HTTP 1.1 Entity tag for the access-control entry. Corresponds to the JSON property etag

Returns:

  • (String)


1354
1355
1356
# File 'lib/google/apis/storage_v1/classes.rb', line 1354

def etag
  @etag
end

#idString

The ID of the access-control entry. Corresponds to the JSON property id

Returns:

  • (String)


1359
1360
1361
# File 'lib/google/apis/storage_v1/classes.rb', line 1359

def id
  @id
end

#kindString

The kind of item this is. For bucket access control entries, this is always storage#bucketAccessControl. Corresponds to the JSON property kind

Returns:

  • (String)


1365
1366
1367
# File 'lib/google/apis/storage_v1/classes.rb', line 1365

def kind
  @kind
end

#project_teamGoogle::Apis::StorageV1::BucketAccessControl::ProjectTeam

The project team associated with the entity, if any. Corresponds to the JSON property projectTeam



1370
1371
1372
# File 'lib/google/apis/storage_v1/classes.rb', line 1370

def project_team
  @project_team
end

#roleString

The access permission for the entity. Corresponds to the JSON property role

Returns:

  • (String)


1375
1376
1377
# File 'lib/google/apis/storage_v1/classes.rb', line 1375

def role
  @role
end

The link to this access-control entry. Corresponds to the JSON property selfLink

Returns:

  • (String)


1380
1381
1382
# File 'lib/google/apis/storage_v1/classes.rb', line 1380

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
# File 'lib/google/apis/storage_v1/classes.rb', line 1387

def update!(**args)
  @bucket = args[:bucket] if args.key?(:bucket)
  @domain = args[:domain] if args.key?(:domain)
  @email = args[:email] if args.key?(:email)
  @entity = args[:entity] if args.key?(:entity)
  @entity_id = args[:entity_id] if args.key?(:entity_id)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @project_team = args[:project_team] if args.key?(:project_team)
  @role = args[:role] if args.key?(:role)
  @self_link = args[:self_link] if args.key?(:self_link)
end