Class: Google::Apis::StorageV1::Buckets

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

A list of buckets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Buckets

Returns a new instance of Buckets.



1561
1562
1563
# File 'lib/google/apis/storage_v1/classes.rb', line 1561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::StorageV1::Bucket>

The list of items. Corresponds to the JSON property items



1542
1543
1544
# File 'lib/google/apis/storage_v1/classes.rb', line 1542

def items
  @items
end

#kindString

The kind of item this is. For lists of buckets, this is always storage#buckets. Corresponds to the JSON property kind

Returns:

  • (String)


1547
1548
1549
# File 'lib/google/apis/storage_v1/classes.rb', line 1547

def kind
  @kind
end

#next_page_tokenString

The continuation token, used to page through large result sets. Provide this value in a subsequent request to return the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1553
1554
1555
# File 'lib/google/apis/storage_v1/classes.rb', line 1553

def next_page_token
  @next_page_token
end

#unreachableArray<String>

The list of bucket resource names that could not be reached during the listing operation. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1559
1560
1561
# File 'lib/google/apis/storage_v1/classes.rb', line 1559

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1566
1567
1568
1569
1570
1571
# File 'lib/google/apis/storage_v1/classes.rb', line 1566

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end