Class: Google::Apis::StorageV1::Channel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

An notification channel used to watch for resource changes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Channel

Returns a new instance of Channel.



1705
1706
1707
# File 'lib/google/apis/storage_v1/classes.rb', line 1705

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

The address where notifications are delivered for this channel. Corresponds to the JSON property address

Returns:

  • (String)


1653
1654
1655
# File 'lib/google/apis/storage_v1/classes.rb', line 1653

def address
  @address
end

#expirationFixnum

Date and time of notification channel expiration, expressed as a Unix timestamp, in milliseconds. Optional. Corresponds to the JSON property expiration

Returns:

  • (Fixnum)


1659
1660
1661
# File 'lib/google/apis/storage_v1/classes.rb', line 1659

def expiration
  @expiration
end

#idString

A UUID or similar unique string that identifies this channel. Corresponds to the JSON property id

Returns:

  • (String)


1664
1665
1666
# File 'lib/google/apis/storage_v1/classes.rb', line 1664

def id
  @id
end

#kindString

Identifies this as a notification channel used to watch for changes to a resource, which is "api#channel". Corresponds to the JSON property kind

Returns:

  • (String)


1670
1671
1672
# File 'lib/google/apis/storage_v1/classes.rb', line 1670

def kind
  @kind
end

#paramsHash<String,String>

Additional parameters controlling delivery channel behavior. Optional. Corresponds to the JSON property params

Returns:

  • (Hash<String,String>)


1675
1676
1677
# File 'lib/google/apis/storage_v1/classes.rb', line 1675

def params
  @params
end

#payloadBoolean Also known as: payload?

A Boolean value to indicate whether payload is wanted. Optional. Corresponds to the JSON property payload

Returns:

  • (Boolean)


1680
1681
1682
# File 'lib/google/apis/storage_v1/classes.rb', line 1680

def payload
  @payload
end

#resource_idString

An opaque ID that identifies the resource being watched on this channel. Stable across different API versions. Corresponds to the JSON property resourceId

Returns:

  • (String)


1687
1688
1689
# File 'lib/google/apis/storage_v1/classes.rb', line 1687

def resource_id
  @resource_id
end

#resource_uriString

A version-specific identifier for the watched resource. Corresponds to the JSON property resourceUri

Returns:

  • (String)


1692
1693
1694
# File 'lib/google/apis/storage_v1/classes.rb', line 1692

def resource_uri
  @resource_uri
end

#tokenString

An arbitrary string delivered to the target address with each notification delivered over this channel. Optional. Corresponds to the JSON property token

Returns:

  • (String)


1698
1699
1700
# File 'lib/google/apis/storage_v1/classes.rb', line 1698

def token
  @token
end

#typeString

The type of delivery mechanism used for this channel. Corresponds to the JSON property type

Returns:

  • (String)


1703
1704
1705
# File 'lib/google/apis/storage_v1/classes.rb', line 1703

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
# File 'lib/google/apis/storage_v1/classes.rb', line 1710

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @expiration = args[:expiration] if args.key?(:expiration)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @params = args[:params] if args.key?(:params)
  @payload = args[:payload] if args.key?(:payload)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @token = args[:token] if args.key?(:token)
  @type = args[:type] if args.key?(:type)
end