Class: Google::Apis::StorageV1::ComposeRequest::SourceObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Defined Under Namespace

Classes: ObjectPreconditions

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceObject

Returns a new instance of SourceObject.



1773
1774
1775
# File 'lib/google/apis/storage_v1/classes.rb', line 1773

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generationFixnum

The generation of this object to use as the source. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


1761
1762
1763
# File 'lib/google/apis/storage_v1/classes.rb', line 1761

def generation
  @generation
end

#nameString

The source object's name. All source objects must reside in the same bucket. Corresponds to the JSON property name

Returns:

  • (String)


1766
1767
1768
# File 'lib/google/apis/storage_v1/classes.rb', line 1766

def name
  @name
end

#object_preconditionsGoogle::Apis::StorageV1::ComposeRequest::SourceObject::ObjectPreconditions

Conditions that must be met for this operation to execute. Corresponds to the JSON property objectPreconditions



1771
1772
1773
# File 'lib/google/apis/storage_v1/classes.rb', line 1771

def object_preconditions
  @object_preconditions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1778
1779
1780
1781
1782
# File 'lib/google/apis/storage_v1/classes.rb', line 1778

def update!(**args)
  @generation = args[:generation] if args.key?(:generation)
  @name = args[:name] if args.key?(:name)
  @object_preconditions = args[:object_preconditions] if args.key?(:object_preconditions)
end