Class: Google::Apis::StorageV1::Folder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

A folder. Only available in buckets with hierarchical namespace enabled.

Defined Under Namespace

Classes: PendingRenameInfo

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Folder

Returns a new instance of Folder.



1921
1922
1923
# File 'lib/google/apis/storage_v1/classes.rb', line 1921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucketString

The name of the bucket containing this folder. Corresponds to the JSON property bucket

Returns:

  • (String)


1877
1878
1879
# File 'lib/google/apis/storage_v1/classes.rb', line 1877

def bucket
  @bucket
end

#create_timeDateTime

The creation time of the folder in RFC 3339 format. Corresponds to the JSON property createTime

Returns:

  • (DateTime)


1882
1883
1884
# File 'lib/google/apis/storage_v1/classes.rb', line 1882

def create_time
  @create_time
end

#idString

The ID of the folder, including the bucket name, folder name. Corresponds to the JSON property id

Returns:

  • (String)


1887
1888
1889
# File 'lib/google/apis/storage_v1/classes.rb', line 1887

def id
  @id
end

#kindString

The kind of item this is. For folders, this is always storage#folder. Corresponds to the JSON property kind

Returns:

  • (String)


1892
1893
1894
# File 'lib/google/apis/storage_v1/classes.rb', line 1892

def kind
  @kind
end

#metagenerationFixnum

The version of the metadata for this folder. Used for preconditions and for detecting changes in metadata. Corresponds to the JSON property metageneration

Returns:

  • (Fixnum)


1898
1899
1900
# File 'lib/google/apis/storage_v1/classes.rb', line 1898

def metageneration
  @metageneration
end

#nameString

The name of the folder. Required if not specified by URL parameter. Corresponds to the JSON property name

Returns:

  • (String)


1903
1904
1905
# File 'lib/google/apis/storage_v1/classes.rb', line 1903

def name
  @name
end

#pending_rename_infoGoogle::Apis::StorageV1::Folder::PendingRenameInfo

Only present if the folder is part of an ongoing rename folder operation. Contains information which can be used to query the operation status. Corresponds to the JSON property pendingRenameInfo



1909
1910
1911
# File 'lib/google/apis/storage_v1/classes.rb', line 1909

def pending_rename_info
  @pending_rename_info
end

The link to this folder. Corresponds to the JSON property selfLink

Returns:

  • (String)


1914
1915
1916
# File 'lib/google/apis/storage_v1/classes.rb', line 1914

def self_link
  @self_link
end

#update_timeDateTime

The modification time of the folder metadata in RFC 3339 format. Corresponds to the JSON property updateTime

Returns:

  • (DateTime)


1919
1920
1921
# File 'lib/google/apis/storage_v1/classes.rb', line 1919

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
# File 'lib/google/apis/storage_v1/classes.rb', line 1926

def update!(**args)
  @bucket = args[:bucket] if args.key?(:bucket)
  @create_time = args[:create_time] if args.key?(:create_time)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @metageneration = args[:metageneration] if args.key?(:metageneration)
  @name = args[:name] if args.key?(:name)
  @pending_rename_info = args[:pending_rename_info] if args.key?(:pending_rename_info)
  @self_link = args[:self_link] if args.key?(:self_link)
  @update_time = args[:update_time] if args.key?(:update_time)
end