Class: Google::Apis::StorageV1::Folder::PendingRenameInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

Only present if the folder is part of an ongoing rename folder operation. Contains information which can be used to query the operation status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PendingRenameInfo

Returns a new instance of PendingRenameInfo.



1936
1937
1938
# File 'lib/google/apis/storage_v1/classes.rb', line 1936

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operation_idString

The ID of the rename folder operation. Corresponds to the JSON property operationId

Returns:

  • (String)


1934
1935
1936
# File 'lib/google/apis/storage_v1/classes.rb', line 1934

def operation_id
  @operation_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1941
1942
1943
# File 'lib/google/apis/storage_v1/classes.rb', line 1941

def update!(**args)
  @operation_id = args[:operation_id] if args.key?(:operation_id)
end