Class: Google::Apis::StorageV1::Folders
- Inherits:
-
Object
- Object
- Google::Apis::StorageV1::Folders
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb
Overview
A list of folders.
Instance Attribute Summary collapse
-
#items ⇒ Array<Google::Apis::StorageV1::Folder>
The list of items.
-
#kind ⇒ String
The kind of item this is.
-
#next_page_token ⇒ String
The continuation token, used to page through large result sets.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Folders
constructor
A new instance of Folders.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Folders
Returns a new instance of Folders.
1960 1961 1962 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1960 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Array<Google::Apis::StorageV1::Folder>
The list of items.
Corresponds to the JSON property items
1947 1948 1949 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1947 def items @items end |
#kind ⇒ String
The kind of item this is. For lists of folders, this is always storage#folders.
Corresponds to the JSON property kind
1952 1953 1954 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1952 def kind @kind end |
#next_page_token ⇒ String
The continuation token, used to page through large result sets. Provide this
value in a subsequent request to return the next page of results.
Corresponds to the JSON property nextPageToken
1958 1959 1960 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1958 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1965 1966 1967 1968 1969 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1965 def update!(**args) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |