Class: Google::Apis::StorageV1::GoogleRpcStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

The "Status" type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each "Status" message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleRpcStatus

Returns a new instance of GoogleRpcStatus.



2123
2124
2125
# File 'lib/google/apis/storage_v1/classes.rb', line 2123

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeFixnum

The status code, which should be an enum value of google.rpc.Code. Corresponds to the JSON property code

Returns:

  • (Fixnum)


2110
2111
2112
# File 'lib/google/apis/storage_v1/classes.rb', line 2110

def code
  @code
end

#detailsArray<Hash<String,Object>>

A list of messages that carry the error details. There is a common set of message types for APIs to use. Corresponds to the JSON property details

Returns:

  • (Array<Hash<String,Object>>)


2116
2117
2118
# File 'lib/google/apis/storage_v1/classes.rb', line 2116

def details
  @details
end

#messageString

A developer-facing error message, which should be in English. Corresponds to the JSON property message

Returns:

  • (String)


2121
2122
2123
# File 'lib/google/apis/storage_v1/classes.rb', line 2121

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2128
2129
2130
2131
2132
# File 'lib/google/apis/storage_v1/classes.rb', line 2128

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @details = args[:details] if args.key?(:details)
  @message = args[:message] if args.key?(:message)
end