Class: Google::Apis::StorageV1::HmacKeyMetadata
- Inherits:
-
Object
- Object
- Google::Apis::StorageV1::HmacKeyMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb
Overview
JSON template to produce a JSON-style HMAC Key metadata resource.
Instance Attribute Summary collapse
-
#access_id ⇒ String
The ID of the HMAC Key.
-
#etag ⇒ String
HTTP 1.1 Entity tag for the HMAC key.
-
#id ⇒ String
The ID of the HMAC key, including the Project ID and the Access ID.
-
#kind ⇒ String
The kind of item this is.
-
#project_id ⇒ String
Project ID owning the service account to which the key authenticates.
-
#self_link ⇒ String
The link to this resource.
-
#service_account_email ⇒ String
The email address of the key's associated service account.
-
#state ⇒ String
The state of the key.
-
#time_created ⇒ DateTime
The creation time of the HMAC key in RFC 3339 format.
-
#updated ⇒ DateTime
The last modification time of the HMAC key metadata in RFC 3339 format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HmacKeyMetadata
constructor
A new instance of HmacKeyMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HmacKeyMetadata
Returns a new instance of HmacKeyMetadata.
2221 2222 2223 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2221 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_id ⇒ String
The ID of the HMAC Key.
Corresponds to the JSON property accessId
2173 2174 2175 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2173 def access_id @access_id end |
#etag ⇒ String
HTTP 1.1 Entity tag for the HMAC key.
Corresponds to the JSON property etag
2178 2179 2180 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2178 def etag @etag end |
#id ⇒ String
The ID of the HMAC key, including the Project ID and the Access ID.
Corresponds to the JSON property id
2183 2184 2185 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2183 def id @id end |
#kind ⇒ String
The kind of item this is. For HMAC Key metadata, this is always storage#
hmacKeyMetadata.
Corresponds to the JSON property kind
2189 2190 2191 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2189 def kind @kind end |
#project_id ⇒ String
Project ID owning the service account to which the key authenticates.
Corresponds to the JSON property projectId
2194 2195 2196 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2194 def project_id @project_id end |
#self_link ⇒ String
The link to this resource.
Corresponds to the JSON property selfLink
2199 2200 2201 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2199 def self_link @self_link end |
#service_account_email ⇒ String
The email address of the key's associated service account.
Corresponds to the JSON property serviceAccountEmail
2204 2205 2206 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2204 def service_account_email @service_account_email end |
#state ⇒ String
The state of the key. Can be one of ACTIVE, INACTIVE, or DELETED.
Corresponds to the JSON property state
2209 2210 2211 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2209 def state @state end |
#time_created ⇒ DateTime
The creation time of the HMAC key in RFC 3339 format.
Corresponds to the JSON property timeCreated
2214 2215 2216 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2214 def time_created @time_created end |
#updated ⇒ DateTime
The last modification time of the HMAC key metadata in RFC 3339 format.
Corresponds to the JSON property updated
2219 2220 2221 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2219 def updated @updated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2226 def update!(**args) @access_id = args[:access_id] if args.key?(:access_id) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @project_id = args[:project_id] if args.key?(:project_id) @self_link = args[:self_link] if args.key?(:self_link) @service_account_email = args[:service_account_email] if args.key?(:service_account_email) @state = args[:state] if args.key?(:state) @time_created = args[:time_created] if args.key?(:time_created) @updated = args[:updated] if args.key?(:updated) end |