Class: Google::Apis::StorageV1::Object::Contexts

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

User-defined or system-defined object contexts. Each object context is a key- payload pair, where the key provides the identification and the payload holds the associated value and additional metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Contexts

Returns a new instance of Contexts.



2747
2748
2749
# File 'lib/google/apis/storage_v1/classes.rb', line 2747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customHash<String,Google::Apis::StorageV1::ObjectCustomContextPayload>

User-defined object contexts. Corresponds to the JSON property custom



2745
2746
2747
# File 'lib/google/apis/storage_v1/classes.rb', line 2745

def custom
  @custom
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2752
2753
2754
# File 'lib/google/apis/storage_v1/classes.rb', line 2752

def update!(**args)
  @custom = args[:custom] if args.key?(:custom)
end