Class: Google::Apis::StorageV1::ObjectAccessControl

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

An access-control entry.

Defined Under Namespace

Classes: ProjectTeam

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ObjectAccessControl

Returns a new instance of ObjectAccessControl.



2941
2942
2943
# File 'lib/google/apis/storage_v1/classes.rb', line 2941

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucketString

The name of the bucket. Corresponds to the JSON property bucket

Returns:

  • (String)


2866
2867
2868
# File 'lib/google/apis/storage_v1/classes.rb', line 2866

def bucket
  @bucket
end

#domainString

The domain associated with the entity, if any. Corresponds to the JSON property domain

Returns:

  • (String)


2871
2872
2873
# File 'lib/google/apis/storage_v1/classes.rb', line 2871

def domain
  @domain
end

#emailString

The email address associated with the entity, if any. Corresponds to the JSON property email

Returns:

  • (String)


2876
2877
2878
# File 'lib/google/apis/storage_v1/classes.rb', line 2876

def email
  @email
end

#entityString

The entity holding the permission, in one of the following forms:

Returns:

  • (String)


2893
2894
2895
# File 'lib/google/apis/storage_v1/classes.rb', line 2893

def entity
  @entity
end

#entity_idString

The ID for the entity, if any. Corresponds to the JSON property entityId

Returns:

  • (String)


2898
2899
2900
# File 'lib/google/apis/storage_v1/classes.rb', line 2898

def entity_id
  @entity_id
end

#etagString

HTTP 1.1 Entity tag for the access-control entry. Corresponds to the JSON property etag

Returns:

  • (String)


2903
2904
2905
# File 'lib/google/apis/storage_v1/classes.rb', line 2903

def etag
  @etag
end

#generationFixnum

The content generation of the object, if applied to an object. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


2908
2909
2910
# File 'lib/google/apis/storage_v1/classes.rb', line 2908

def generation
  @generation
end

#idString

The ID of the access-control entry. Corresponds to the JSON property id

Returns:

  • (String)


2913
2914
2915
# File 'lib/google/apis/storage_v1/classes.rb', line 2913

def id
  @id
end

#kindString

The kind of item this is. For object access control entries, this is always storage#objectAccessControl. Corresponds to the JSON property kind

Returns:

  • (String)


2919
2920
2921
# File 'lib/google/apis/storage_v1/classes.rb', line 2919

def kind
  @kind
end

#objectString

The name of the object, if applied to an object. Corresponds to the JSON property object

Returns:

  • (String)


2924
2925
2926
# File 'lib/google/apis/storage_v1/classes.rb', line 2924

def object
  @object
end

#project_teamGoogle::Apis::StorageV1::ObjectAccessControl::ProjectTeam

The project team associated with the entity, if any. Corresponds to the JSON property projectTeam



2929
2930
2931
# File 'lib/google/apis/storage_v1/classes.rb', line 2929

def project_team
  @project_team
end

#roleString

The access permission for the entity. Corresponds to the JSON property role

Returns:

  • (String)


2934
2935
2936
# File 'lib/google/apis/storage_v1/classes.rb', line 2934

def role
  @role
end

The link to this access-control entry. Corresponds to the JSON property selfLink

Returns:

  • (String)


2939
2940
2941
# File 'lib/google/apis/storage_v1/classes.rb', line 2939

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2946
2947
2948
2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
# File 'lib/google/apis/storage_v1/classes.rb', line 2946

def update!(**args)
  @bucket = args[:bucket] if args.key?(:bucket)
  @domain = args[:domain] if args.key?(:domain)
  @email = args[:email] if args.key?(:email)
  @entity = args[:entity] if args.key?(:entity)
  @entity_id = args[:entity_id] if args.key?(:entity_id)
  @etag = args[:etag] if args.key?(:etag)
  @generation = args[:generation] if args.key?(:generation)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @object = args[:object] if args.key?(:object)
  @project_team = args[:project_team] if args.key?(:project_team)
  @role = args[:role] if args.key?(:role)
  @self_link = args[:self_link] if args.key?(:self_link)
end