Class: Google::Apis::StorageV1::Objects

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

A list of objects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Objects

Returns a new instance of Objects.



3046
3047
3048
# File 'lib/google/apis/storage_v1/classes.rb', line 3046

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::StorageV1::Object>

The list of items. Corresponds to the JSON property items



3027
3028
3029
# File 'lib/google/apis/storage_v1/classes.rb', line 3027

def items
  @items
end

#kindString

The kind of item this is. For lists of objects, this is always storage#objects. Corresponds to the JSON property kind

Returns:

  • (String)


3032
3033
3034
# File 'lib/google/apis/storage_v1/classes.rb', line 3032

def kind
  @kind
end

#next_page_tokenString

The continuation token, used to page through large result sets. Provide this value in a subsequent request to return the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3038
3039
3040
# File 'lib/google/apis/storage_v1/classes.rb', line 3038

def next_page_token
  @next_page_token
end

#prefixesArray<String>

The list of prefixes of objects matching-but-not-listed up to and including the requested delimiter. Corresponds to the JSON property prefixes

Returns:

  • (Array<String>)


3044
3045
3046
# File 'lib/google/apis/storage_v1/classes.rb', line 3044

def prefixes
  @prefixes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3051
3052
3053
3054
3055
3056
# File 'lib/google/apis/storage_v1/classes.rb', line 3051

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @prefixes = args[:prefixes] if args.key?(:prefixes)
end