Class: Google::Apis::StorageV1::RapidCache

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

A Rapid Cache instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RapidCache

Returns a new instance of RapidCache.



3288
3289
3290
# File 'lib/google/apis/storage_v1/classes.rb', line 3288

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admission_policyString

The cache-level entry admission policy. Corresponds to the JSON property admissionPolicy

Returns:

  • (String)


3217
3218
3219
# File 'lib/google/apis/storage_v1/classes.rb', line 3217

def admission_policy
  @admission_policy
end

#bucketString

The name of the bucket containing this cache instance. Corresponds to the JSON property bucket

Returns:

  • (String)


3222
3223
3224
# File 'lib/google/apis/storage_v1/classes.rb', line 3222

def bucket
  @bucket
end

#cache_typeString

The type of Rapid Cache this represents. Valid values include: "rapid-cache" and "rapid-cache-ultra". Corresponds to the JSON property cacheType

Returns:

  • (String)


3228
3229
3230
# File 'lib/google/apis/storage_v1/classes.rb', line 3228

def cache_type
  @cache_type
end

#create_timeDateTime

The creation time of the cache instance in RFC 3339 format. Corresponds to the JSON property createTime

Returns:

  • (DateTime)


3233
3234
3235
# File 'lib/google/apis/storage_v1/classes.rb', line 3233

def create_time
  @create_time
end

#idString

The ID of the resource, including the project number, bucket name and rapid cache ID. Corresponds to the JSON property id

Returns:

  • (String)


3239
3240
3241
# File 'lib/google/apis/storage_v1/classes.rb', line 3239

def id
  @id
end

#ingest_on_writeBoolean Also known as: ingest_on_write?

Specifies whether objects are ingested into the cache upon write. Corresponds to the JSON property ingestOnWrite

Returns:

  • (Boolean)


3244
3245
3246
# File 'lib/google/apis/storage_v1/classes.rb', line 3244

def ingest_on_write
  @ingest_on_write
end

#kindString

The kind of item this is. For Rapid Cache, this is always storage#rapidCache. Corresponds to the JSON property kind

Returns:

  • (String)


3250
3251
3252
# File 'lib/google/apis/storage_v1/classes.rb', line 3250

def kind
  @kind
end

#pending_updateBoolean Also known as: pending_update?

True if the cache instance has an active Update long-running operation. Corresponds to the JSON property pendingUpdate

Returns:

  • (Boolean)


3255
3256
3257
# File 'lib/google/apis/storage_v1/classes.rb', line 3255

def pending_update
  @pending_update
end

#rapid_cache_idString

The ID of the Rapid cache instance. Corresponds to the JSON property rapidCacheId

Returns:

  • (String)


3261
3262
3263
# File 'lib/google/apis/storage_v1/classes.rb', line 3261

def rapid_cache_id
  @rapid_cache_id
end

The link to this cache instance. Corresponds to the JSON property selfLink

Returns:

  • (String)


3266
3267
3268
# File 'lib/google/apis/storage_v1/classes.rb', line 3266

def self_link
  @self_link
end

#stateString

The current state of the cache instance. Corresponds to the JSON property state

Returns:

  • (String)


3271
3272
3273
# File 'lib/google/apis/storage_v1/classes.rb', line 3271

def state
  @state
end

#ttlString

The TTL of all cache entries in whole seconds. e.g., "7200s". Corresponds to the JSON property ttl

Returns:

  • (String)


3276
3277
3278
# File 'lib/google/apis/storage_v1/classes.rb', line 3276

def ttl
  @ttl
end

#update_timeDateTime

The modification time of the cache instance metadata in RFC 3339 format. Corresponds to the JSON property updateTime

Returns:

  • (DateTime)


3281
3282
3283
# File 'lib/google/apis/storage_v1/classes.rb', line 3281

def update_time
  @update_time
end

#zoneString

The zone in which the cache instance is running. For example, us-central1-a. Corresponds to the JSON property zone

Returns:

  • (String)


3286
3287
3288
# File 'lib/google/apis/storage_v1/classes.rb', line 3286

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3293
3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
# File 'lib/google/apis/storage_v1/classes.rb', line 3293

def update!(**args)
  @admission_policy = args[:admission_policy] if args.key?(:admission_policy)
  @bucket = args[:bucket] if args.key?(:bucket)
  @cache_type = args[:cache_type] if args.key?(:cache_type)
  @create_time = args[:create_time] if args.key?(:create_time)
  @id = args[:id] if args.key?(:id)
  @ingest_on_write = args[:ingest_on_write] if args.key?(:ingest_on_write)
  @kind = args[:kind] if args.key?(:kind)
  @pending_update = args[:pending_update] if args.key?(:pending_update)
  @rapid_cache_id = args[:rapid_cache_id] if args.key?(:rapid_cache_id)
  @self_link = args[:self_link] if args.key?(:self_link)
  @state = args[:state] if args.key?(:state)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
  @zone = args[:zone] if args.key?(:zone)
end