Class: Google::Apis::StorageV1::RelocateBucketRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

A Relocate Bucket request.

Defined Under Namespace

Classes: DestinationCustomPlacementConfig

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RelocateBucketRequest

Returns a new instance of RelocateBucketRequest.



3419
3420
3421
# File 'lib/google/apis/storage_v1/classes.rb', line 3419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_custom_placement_configGoogle::Apis::StorageV1::RelocateBucketRequest::DestinationCustomPlacementConfig

The bucket's new custom placement configuration if relocating to a Custom Dual Region. Corresponds to the JSON property destinationCustomPlacementConfig



3399
3400
3401
# File 'lib/google/apis/storage_v1/classes.rb', line 3399

def destination_custom_placement_config
  @destination_custom_placement_config
end

#destination_kms_key_nameString

Resource name of a Cloud KMS key, of the form projects/my-project/locations/ global/keyRings/my-kr/cryptoKeys/my-key. If set, is used to encrypt all objects in the destination bucket. Corresponds to the JSON property destinationKmsKeyName

Returns:

  • (String)


3406
3407
3408
# File 'lib/google/apis/storage_v1/classes.rb', line 3406

def destination_kms_key_name
  @destination_kms_key_name
end

#destination_locationString

The new location the bucket will be relocated to. Corresponds to the JSON property destinationLocation

Returns:

  • (String)


3411
3412
3413
# File 'lib/google/apis/storage_v1/classes.rb', line 3411

def destination_location
  @destination_location
end

#validate_onlyBoolean Also known as: validate_only?

If true, validate the operation, but do not actually relocate the bucket. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


3416
3417
3418
# File 'lib/google/apis/storage_v1/classes.rb', line 3416

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3424
3425
3426
3427
3428
3429
# File 'lib/google/apis/storage_v1/classes.rb', line 3424

def update!(**args)
  @destination_custom_placement_config = args[:destination_custom_placement_config] if args.key?(:destination_custom_placement_config)
  @destination_kms_key_name = args[:destination_kms_key_name] if args.key?(:destination_kms_key_name)
  @destination_location = args[:destination_location] if args.key?(:destination_location)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end