Class: Google::Apis::StorageV1::RewriteResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

A rewrite response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RewriteResponse

Returns a new instance of RewriteResponse.



3491
3492
3493
# File 'lib/google/apis/storage_v1/classes.rb', line 3491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#doneBoolean Also known as: done?

true if the copy is finished; otherwise, false if the copy is in progress. This property is always present in the response. Corresponds to the JSON property done

Returns:

  • (Boolean)


3460
3461
3462
# File 'lib/google/apis/storage_v1/classes.rb', line 3460

def done
  @done
end

#kindString

The kind of item this is. Corresponds to the JSON property kind

Returns:

  • (String)


3466
3467
3468
# File 'lib/google/apis/storage_v1/classes.rb', line 3466

def kind
  @kind
end

#object_sizeFixnum

The total size of the object being copied in bytes. This property is always present in the response. Corresponds to the JSON property objectSize

Returns:

  • (Fixnum)


3472
3473
3474
# File 'lib/google/apis/storage_v1/classes.rb', line 3472

def object_size
  @object_size
end

#resourceGoogle::Apis::StorageV1::Object

An object. Corresponds to the JSON property resource



3477
3478
3479
# File 'lib/google/apis/storage_v1/classes.rb', line 3477

def resource
  @resource
end

#rewrite_tokenString

A token to use in subsequent requests to continue copying data. This token is present in the response only when there is more data to copy. Corresponds to the JSON property rewriteToken

Returns:

  • (String)


3483
3484
3485
# File 'lib/google/apis/storage_v1/classes.rb', line 3483

def rewrite_token
  @rewrite_token
end

#total_bytes_rewrittenFixnum

The total bytes written so far, which can be used to provide a waiting user with a progress indicator. This property is always present in the response. Corresponds to the JSON property totalBytesRewritten

Returns:

  • (Fixnum)


3489
3490
3491
# File 'lib/google/apis/storage_v1/classes.rb', line 3489

def total_bytes_rewritten
  @total_bytes_rewritten
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3496
3497
3498
3499
3500
3501
3502
3503
# File 'lib/google/apis/storage_v1/classes.rb', line 3496

def update!(**args)
  @done = args[:done] if args.key?(:done)
  @kind = args[:kind] if args.key?(:kind)
  @object_size = args[:object_size] if args.key?(:object_size)
  @resource = args[:resource] if args.key?(:resource)
  @rewrite_token = args[:rewrite_token] if args.key?(:rewrite_token)
  @total_bytes_rewritten = args[:total_bytes_rewritten] if args.key?(:total_bytes_rewritten)
end