Class: Google::Apis::StorageV1::Bucket::Encryption::CustomerSuppliedEncryptionEnforcementConfig
- Inherits:
-
Object
- Object
- Google::Apis::StorageV1::Bucket::Encryption::CustomerSuppliedEncryptionEnforcementConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb
Overview
If set, the new objects created in this bucket must comply with this enforcement config. Changing this has no effect on existing objects; it applies to new objects only. If omitted, the new objects are allowed to be encrypted with Customer Supplied Encryption type by default.
Instance Attribute Summary collapse
-
#effective_time ⇒ DateTime
Server-determined value that indicates the time from which configuration was enforced and effective.
-
#restriction_mode ⇒ String
Restriction mode for Customer-Supplied Encryption Keys.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomerSuppliedEncryptionEnforcementConfig
constructor
A new instance of CustomerSuppliedEncryptionEnforcementConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomerSuppliedEncryptionEnforcementConfig
Returns a new instance of CustomerSuppliedEncryptionEnforcementConfig.
671 672 673 |
# File 'lib/google/apis/storage_v1/classes.rb', line 671 def initialize(**args) update!(**args) end |
Instance Attribute Details
#effective_time ⇒ DateTime
Server-determined value that indicates the time from which configuration was
enforced and effective. This value is in RFC 3339 format.
Corresponds to the JSON property effectiveTime
663 664 665 |
# File 'lib/google/apis/storage_v1/classes.rb', line 663 def effective_time @effective_time end |
#restriction_mode ⇒ String
Restriction mode for Customer-Supplied Encryption Keys. Defaults to
NotRestricted.
Corresponds to the JSON property restrictionMode
669 670 671 |
# File 'lib/google/apis/storage_v1/classes.rb', line 669 def restriction_mode @restriction_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
676 677 678 679 |
# File 'lib/google/apis/storage_v1/classes.rb', line 676 def update!(**args) @effective_time = args[:effective_time] if args.key?(:effective_time) @restriction_mode = args[:restriction_mode] if args.key?(:restriction_mode) end |