Class: Google::Apis::StorageV1::Bucket::Encryption::GoogleManagedEncryptionEnforcementConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

If set, the new objects created in this bucket must comply with this enforcement config. Changing this has no effect on existing objects; it applies to new objects only. If omitted, the new objects are allowed to be encrypted with Google Managed Encryption type by default.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleManagedEncryptionEnforcementConfig

Returns a new instance of GoogleManagedEncryptionEnforcementConfig.



700
701
702
# File 'lib/google/apis/storage_v1/classes.rb', line 700

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_timeDateTime

Server-determined value that indicates the time from which configuration was enforced and effective. This value is in RFC 3339 format. Corresponds to the JSON property effectiveTime

Returns:

  • (DateTime)


693
694
695
# File 'lib/google/apis/storage_v1/classes.rb', line 693

def effective_time
  @effective_time
end

#restriction_modeString

Restriction mode for Google-Managed Encryption Keys. Defaults to NotRestricted. Corresponds to the JSON property restrictionMode

Returns:

  • (String)


698
699
700
# File 'lib/google/apis/storage_v1/classes.rb', line 698

def restriction_mode
  @restriction_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



705
706
707
708
# File 'lib/google/apis/storage_v1/classes.rb', line 705

def update!(**args)
  @effective_time = args[:effective_time] if args.key?(:effective_time)
  @restriction_mode = args[:restriction_mode] if args.key?(:restriction_mode)
end