Class: Google::Apis::StorageV1::BucketAccessControl

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

An access-control entry.

Defined Under Namespace

Classes: ProjectTeam

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BucketAccessControl

Returns a new instance of BucketAccessControl.



1375
1376
1377
# File 'lib/google/apis/storage_v1/classes.rb', line 1375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucketString

The name of the bucket. Corresponds to the JSON property bucket

Returns:

  • (String)


1310
1311
1312
# File 'lib/google/apis/storage_v1/classes.rb', line 1310

def bucket
  @bucket
end

#domainString

The domain associated with the entity, if any. Corresponds to the JSON property domain

Returns:

  • (String)


1315
1316
1317
# File 'lib/google/apis/storage_v1/classes.rb', line 1315

def domain
  @domain
end

#emailString

The email address associated with the entity, if any. Corresponds to the JSON property email

Returns:

  • (String)


1320
1321
1322
# File 'lib/google/apis/storage_v1/classes.rb', line 1320

def email
  @email
end

#entityString

The entity holding the permission, in one of the following forms:

Returns:

  • (String)


1337
1338
1339
# File 'lib/google/apis/storage_v1/classes.rb', line 1337

def entity
  @entity
end

#entity_idString

The ID for the entity, if any. Corresponds to the JSON property entityId

Returns:

  • (String)


1342
1343
1344
# File 'lib/google/apis/storage_v1/classes.rb', line 1342

def entity_id
  @entity_id
end

#etagString

HTTP 1.1 Entity tag for the access-control entry. Corresponds to the JSON property etag

Returns:

  • (String)


1347
1348
1349
# File 'lib/google/apis/storage_v1/classes.rb', line 1347

def etag
  @etag
end

#idString

The ID of the access-control entry. Corresponds to the JSON property id

Returns:

  • (String)


1352
1353
1354
# File 'lib/google/apis/storage_v1/classes.rb', line 1352

def id
  @id
end

#kindString

The kind of item this is. For bucket access control entries, this is always storage#bucketAccessControl. Corresponds to the JSON property kind

Returns:

  • (String)


1358
1359
1360
# File 'lib/google/apis/storage_v1/classes.rb', line 1358

def kind
  @kind
end

#project_teamGoogle::Apis::StorageV1::BucketAccessControl::ProjectTeam

The project team associated with the entity, if any. Corresponds to the JSON property projectTeam



1363
1364
1365
# File 'lib/google/apis/storage_v1/classes.rb', line 1363

def project_team
  @project_team
end

#roleString

The access permission for the entity. Corresponds to the JSON property role

Returns:

  • (String)


1368
1369
1370
# File 'lib/google/apis/storage_v1/classes.rb', line 1368

def role
  @role
end

The link to this access-control entry. Corresponds to the JSON property selfLink

Returns:

  • (String)


1373
1374
1375
# File 'lib/google/apis/storage_v1/classes.rb', line 1373

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
# File 'lib/google/apis/storage_v1/classes.rb', line 1380

def update!(**args)
  @bucket = args[:bucket] if args.key?(:bucket)
  @domain = args[:domain] if args.key?(:domain)
  @email = args[:email] if args.key?(:email)
  @entity = args[:entity] if args.key?(:entity)
  @entity_id = args[:entity_id] if args.key?(:entity_id)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @project_team = args[:project_team] if args.key?(:project_team)
  @role = args[:role] if args.key?(:role)
  @self_link = args[:self_link] if args.key?(:self_link)
end