Class: Google::Apis::StorageV1::BulkRestoreObjectsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

A bulk restore objects request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkRestoreObjectsRequest

Returns a new instance of BulkRestoreObjectsRequest.



1623
1624
1625
# File 'lib/google/apis/storage_v1/classes.rb', line 1623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_overwriteBoolean Also known as: allow_overwrite?

If false (default), the restore will not overwrite live objects with the same name at the destination. This means some deleted objects may be skipped. If true, live objects will be overwritten resulting in a noncurrent object (if versioning is enabled). If versioning is not enabled, overwriting the object will result in a soft-deleted object. In either case, if a noncurrent object already exists with the same name, a live version can be written without issue. Corresponds to the JSON property allowOverwrite

Returns:

  • (Boolean)


1586
1587
1588
# File 'lib/google/apis/storage_v1/classes.rb', line 1586

def allow_overwrite
  @allow_overwrite
end

#copy_source_aclBoolean Also known as: copy_source_acl?

If true, copies the source object's ACL; otherwise, uses the bucket's default object ACL. The default is false. Corresponds to the JSON property copySourceAcl

Returns:

  • (Boolean)


1593
1594
1595
# File 'lib/google/apis/storage_v1/classes.rb', line 1593

def copy_source_acl
  @copy_source_acl
end

#created_after_timeDateTime

Restores only the objects that were created after this time. Corresponds to the JSON property createdAfterTime

Returns:

  • (DateTime)


1599
1600
1601
# File 'lib/google/apis/storage_v1/classes.rb', line 1599

def created_after_time
  @created_after_time
end

#created_before_timeDateTime

Restores only the objects that were created before this time. Corresponds to the JSON property createdBeforeTime

Returns:

  • (DateTime)


1604
1605
1606
# File 'lib/google/apis/storage_v1/classes.rb', line 1604

def created_before_time
  @created_before_time
end

#match_globsArray<String>

Restores only the objects matching any of the specified glob(s). If this parameter is not specified, all objects will be restored within the specified time range. Corresponds to the JSON property matchGlobs

Returns:

  • (Array<String>)


1611
1612
1613
# File 'lib/google/apis/storage_v1/classes.rb', line 1611

def match_globs
  @match_globs
end

#soft_deleted_after_timeDateTime

Restores only the objects that were soft-deleted after this time. Corresponds to the JSON property softDeletedAfterTime

Returns:

  • (DateTime)


1616
1617
1618
# File 'lib/google/apis/storage_v1/classes.rb', line 1616

def soft_deleted_after_time
  @soft_deleted_after_time
end

#soft_deleted_before_timeDateTime

Restores only the objects that were soft-deleted before this time. Corresponds to the JSON property softDeletedBeforeTime

Returns:

  • (DateTime)


1621
1622
1623
# File 'lib/google/apis/storage_v1/classes.rb', line 1621

def soft_deleted_before_time
  @soft_deleted_before_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1628
1629
1630
1631
1632
1633
1634
1635
1636
# File 'lib/google/apis/storage_v1/classes.rb', line 1628

def update!(**args)
  @allow_overwrite = args[:allow_overwrite] if args.key?(:allow_overwrite)
  @copy_source_acl = args[:copy_source_acl] if args.key?(:copy_source_acl)
  @created_after_time = args[:created_after_time] if args.key?(:created_after_time)
  @created_before_time = args[:created_before_time] if args.key?(:created_before_time)
  @match_globs = args[:match_globs] if args.key?(:match_globs)
  @soft_deleted_after_time = args[:soft_deleted_after_time] if args.key?(:soft_deleted_after_time)
  @soft_deleted_before_time = args[:soft_deleted_before_time] if args.key?(:soft_deleted_before_time)
end