Class: Google::Apis::StorageV1::Channel
- Inherits:
-
Object
- Object
- Google::Apis::StorageV1::Channel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb
Overview
An notification channel used to watch for resource changes.
Instance Attribute Summary collapse
-
#address ⇒ String
The address where notifications are delivered for this channel.
-
#expiration ⇒ Fixnum
Date and time of notification channel expiration, expressed as a Unix timestamp, in milliseconds.
-
#id ⇒ String
A UUID or similar unique string that identifies this channel.
-
#kind ⇒ String
Identifies this as a notification channel used to watch for changes to a resource, which is "api#channel".
-
#params ⇒ Hash<String,String>
Additional parameters controlling delivery channel behavior.
-
#payload ⇒ Boolean
(also: #payload?)
A Boolean value to indicate whether payload is wanted.
-
#resource_id ⇒ String
An opaque ID that identifies the resource being watched on this channel.
-
#resource_uri ⇒ String
A version-specific identifier for the watched resource.
-
#token ⇒ String
An arbitrary string delivered to the target address with each notification delivered over this channel.
-
#type ⇒ String
The type of delivery mechanism used for this channel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Channel
constructor
A new instance of Channel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Channel
Returns a new instance of Channel.
1698 1699 1700 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1698 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
The address where notifications are delivered for this channel.
Corresponds to the JSON property address
1646 1647 1648 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1646 def address @address end |
#expiration ⇒ Fixnum
Date and time of notification channel expiration, expressed as a Unix
timestamp, in milliseconds. Optional.
Corresponds to the JSON property expiration
1652 1653 1654 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1652 def expiration @expiration end |
#id ⇒ String
A UUID or similar unique string that identifies this channel.
Corresponds to the JSON property id
1657 1658 1659 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1657 def id @id end |
#kind ⇒ String
Identifies this as a notification channel used to watch for changes to a
resource, which is "api#channel".
Corresponds to the JSON property kind
1663 1664 1665 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1663 def kind @kind end |
#params ⇒ Hash<String,String>
Additional parameters controlling delivery channel behavior. Optional.
Corresponds to the JSON property params
1668 1669 1670 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1668 def params @params end |
#payload ⇒ Boolean Also known as: payload?
A Boolean value to indicate whether payload is wanted. Optional.
Corresponds to the JSON property payload
1673 1674 1675 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1673 def payload @payload end |
#resource_id ⇒ String
An opaque ID that identifies the resource being watched on this channel.
Stable across different API versions.
Corresponds to the JSON property resourceId
1680 1681 1682 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1680 def resource_id @resource_id end |
#resource_uri ⇒ String
A version-specific identifier for the watched resource.
Corresponds to the JSON property resourceUri
1685 1686 1687 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1685 def resource_uri @resource_uri end |
#token ⇒ String
An arbitrary string delivered to the target address with each notification
delivered over this channel. Optional.
Corresponds to the JSON property token
1691 1692 1693 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1691 def token @token end |
#type ⇒ String
The type of delivery mechanism used for this channel.
Corresponds to the JSON property type
1696 1697 1698 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1696 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1703 def update!(**args) @address = args[:address] if args.key?(:address) @expiration = args[:expiration] if args.key?(:expiration) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @params = args[:params] if args.key?(:params) @payload = args[:payload] if args.key?(:payload) @resource_id = args[:resource_id] if args.key?(:resource_id) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @token = args[:token] if args.key?(:token) @type = args[:type] if args.key?(:type) end |