Class: Google::Apis::StorageV1::ComposeRequest
- Inherits:
-
Object
- Object
- Google::Apis::StorageV1::ComposeRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb
Overview
A Compose request.
Defined Under Namespace
Classes: SourceObject
Instance Attribute Summary collapse
-
#delete_source_objects ⇒ Boolean
(also: #delete_source_objects?)
If true, the source objects will be deleted.
-
#destination ⇒ Google::Apis::StorageV1::Object
An object.
-
#kind ⇒ String
The kind of item this is.
-
#source_objects ⇒ Array<Google::Apis::StorageV1::ComposeRequest::SourceObject>
The list of source objects that will be concatenated into a single object.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ComposeRequest
constructor
A new instance of ComposeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ComposeRequest
Returns a new instance of ComposeRequest.
1749 1750 1751 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1749 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delete_source_objects ⇒ Boolean Also known as: delete_source_objects?
If true, the source objects will be deleted.
Corresponds to the JSON property deleteSourceObjects
1731 1732 1733 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1731 def delete_source_objects @delete_source_objects end |
#destination ⇒ Google::Apis::StorageV1::Object
An object.
Corresponds to the JSON property destination
1737 1738 1739 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1737 def destination @destination end |
#kind ⇒ String
The kind of item this is.
Corresponds to the JSON property kind
1742 1743 1744 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1742 def kind @kind end |
#source_objects ⇒ Array<Google::Apis::StorageV1::ComposeRequest::SourceObject>
The list of source objects that will be concatenated into a single object.
Corresponds to the JSON property sourceObjects
1747 1748 1749 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1747 def source_objects @source_objects end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1754 1755 1756 1757 1758 1759 |
# File 'lib/google/apis/storage_v1/classes.rb', line 1754 def update!(**args) @delete_source_objects = args[:delete_source_objects] if args.key?(:delete_source_objects) @destination = args[:destination] if args.key?(:destination) @kind = args[:kind] if args.key?(:kind) @source_objects = args[:source_objects] if args.key?(:source_objects) end |