Class: Google::Apis::StorageV1::GoogleLongrunningOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

This resource represents a long-running operation that is the result of a network API call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleLongrunningOperation

Returns a new instance of GoogleLongrunningOperation.



2070
2071
2072
# File 'lib/google/apis/storage_v1/classes.rb', line 2070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#doneBoolean Also known as: done?

If the value is "false", it means the operation is still in progress. If "true" , the operation is completed, and either "error" or "response" is available. Corresponds to the JSON property done

Returns:

  • (Boolean)


2021
2022
2023
# File 'lib/google/apis/storage_v1/classes.rb', line 2021

def done
  @done
end

#errorGoogle::Apis::StorageV1::GoogleRpcStatus

The "Status" type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each "Status" message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



2032
2033
2034
# File 'lib/google/apis/storage_v1/classes.rb', line 2032

def error
  @error
end

#kindString

The kind of item this is. For operations, this is always storage#operation. Corresponds to the JSON property kind

Returns:

  • (String)


2037
2038
2039
# File 'lib/google/apis/storage_v1/classes.rb', line 2037

def kind
  @kind
end

#metadataHash<String,Object>

Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any. Corresponds to the JSON property metadata

Returns:



2045
2046
2047
# File 'lib/google/apis/storage_v1/classes.rb', line 2045

def 
  @metadata
end

#nameString

The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the "name" should be a resource name ending with "operations/operationId". Corresponds to the JSON property name

Returns:

  • (String)


2052
2053
2054
# File 'lib/google/apis/storage_v1/classes.rb', line 2052

def name
  @name
end

#responseHash<String,Object>

The normal response of the operation in case of success. If the original method returns no data on success, such as "Delete", the response is google. protobuf.Empty. If the original method is standard Get/Create/Update, the response should be the resource. For other methods, the response should have the type "XxxResponse", where "Xxx" is the original method name. For example, if the original method name is "TakeSnapshot()", the inferred response type is "TakeSnapshotResponse". Corresponds to the JSON property response

Returns:



2063
2064
2065
# File 'lib/google/apis/storage_v1/classes.rb', line 2063

def response
  @response
end

The link to this long running operation. Corresponds to the JSON property selfLink

Returns:

  • (String)


2068
2069
2070
# File 'lib/google/apis/storage_v1/classes.rb', line 2068

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2075
2076
2077
2078
2079
2080
2081
2082
2083
# File 'lib/google/apis/storage_v1/classes.rb', line 2075

def update!(**args)
  @done = args[:done] if args.key?(:done)
  @error = args[:error] if args.key?(:error)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @response = args[:response] if args.key?(:response)
  @self_link = args[:self_link] if args.key?(:self_link)
end