Class: Google::Apis::StorageV1::GoogleRpcStatus
- Inherits:
-
Object
- Object
- Google::Apis::StorageV1::GoogleRpcStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb
Overview
The "Status" type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each "Status" message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide.
Instance Attribute Summary collapse
-
#code ⇒ Fixnum
The status code, which should be an enum value of google.rpc.Code.
-
#details ⇒ Array<Hash<String,Object>>
A list of messages that carry the error details.
-
#message ⇒ String
A developer-facing error message, which should be in English.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleRpcStatus
constructor
A new instance of GoogleRpcStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleRpcStatus
Returns a new instance of GoogleRpcStatus.
2111 2112 2113 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2111 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ Fixnum
The status code, which should be an enum value of google.rpc.Code.
Corresponds to the JSON property code
2098 2099 2100 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2098 def code @code end |
#details ⇒ Array<Hash<String,Object>>
A list of messages that carry the error details. There is a common set of
message types for APIs to use.
Corresponds to the JSON property details
2104 2105 2106 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2104 def details @details end |
#message ⇒ String
A developer-facing error message, which should be in English.
Corresponds to the JSON property message
2109 2110 2111 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2109 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2116 2117 2118 2119 2120 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2116 def update!(**args) @code = args[:code] if args.key?(:code) @details = args[:details] if args.key?(:details) @message = args[:message] if args.key?(:message) end |