Class: Google::Apis::StorageV1::Object
- Inherits:
-
Object
- Object
- Google::Apis::StorageV1::Object
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb
Overview
An object.
Defined Under Namespace
Classes: Contexts, CustomerEncryption, Owner, Retention
Instance Attribute Summary collapse
-
#acl ⇒ Array<Google::Apis::StorageV1::ObjectAccessControl>
Access controls on the object.
-
#bucket ⇒ String
The name of the bucket containing this object.
-
#cache_control ⇒ String
Cache-Control directive for the object data.
-
#component_count ⇒ Fixnum
Number of underlying components that make up this object.
-
#content_disposition ⇒ String
Content-Disposition of the object data.
-
#content_encoding ⇒ String
Content-Encoding of the object data.
-
#content_language ⇒ String
Content-Language of the object data.
-
#content_type ⇒ String
Content-Type of the object data.
-
#contexts ⇒ Google::Apis::StorageV1::Object::Contexts
User-defined or system-defined object contexts.
-
#crc32c ⇒ String
CRC32c checksum, as described in RFC 4960, Appendix B; encoded using base64 in big-endian byte order.
-
#custom_time ⇒ DateTime
A timestamp in RFC 3339 format specified by the user for an object.
-
#customer_encryption ⇒ Google::Apis::StorageV1::Object::CustomerEncryption
Metadata of customer-supplied encryption key, if the object is encrypted by such a key.
-
#etag ⇒ String
HTTP 1.1 Entity tag for the object.
-
#event_based_hold ⇒ Boolean
(also: #event_based_hold?)
Whether an object is under event-based hold.
-
#generation ⇒ Fixnum
The content generation of this object.
-
#hard_delete_time ⇒ DateTime
This is the time (in the future) when the soft-deleted object will no longer be restorable.
-
#id ⇒ String
The ID of the object, including the bucket name, object name, and generation number.
-
#kind ⇒ String
The kind of item this is.
-
#kms_key_name ⇒ String
Not currently supported.
-
#md5_hash ⇒ String
MD5 hash of the data; encoded using base64.
-
#media_link ⇒ String
Media download link.
-
#metadata ⇒ Hash<String,String>
User-provided metadata, in key/value pairs.
-
#metageneration ⇒ Fixnum
The version of the metadata for this object at this generation.
-
#name ⇒ String
The name of the object.
-
#owner ⇒ Google::Apis::StorageV1::Object::Owner
The owner of the object.
-
#restore_token ⇒ String
Restore token used to differentiate deleted objects with the same name and generation.
-
#retention ⇒ Google::Apis::StorageV1::Object::Retention
A collection of object level retention parameters.
-
#retention_expiration_time ⇒ DateTime
A server-determined value that specifies the earliest time that the object's retention period expires.
-
#self_link ⇒ String
The link to this object.
-
#size ⇒ Fixnum
Content-Length of the data in bytes.
-
#soft_delete_time ⇒ DateTime
The time at which the object became soft-deleted in RFC 3339 format.
-
#storage_class ⇒ String
Storage class of the object.
-
#temporary_hold ⇒ Boolean
(also: #temporary_hold?)
Whether an object is under temporary hold.
-
#time_created ⇒ DateTime
The creation time of the object in RFC 3339 format.
-
#time_deleted ⇒ DateTime
The time at which the object became noncurrent in RFC 3339 format.
-
#time_finalized ⇒ DateTime
The time when the object was finalized.
-
#time_storage_class_updated ⇒ DateTime
The time at which the object's storage class was last changed.
-
#updated ⇒ DateTime
The modification time of the object metadata in RFC 3339 format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Object
constructor
A new instance of Object.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Object
Returns a new instance of Object.
2709 2710 2711 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2709 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acl ⇒ Array<Google::Apis::StorageV1::ObjectAccessControl>
Access controls on the object.
Corresponds to the JSON property acl
2475 2476 2477 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2475 def acl @acl end |
#bucket ⇒ String
The name of the bucket containing this object.
Corresponds to the JSON property bucket
2480 2481 2482 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2480 def bucket @bucket end |
#cache_control ⇒ String
Cache-Control directive for the object data. If omitted, and the object is
accessible to all anonymous users, the default will be public, max-age=3600.
Corresponds to the JSON property cacheControl
2486 2487 2488 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2486 def cache_control @cache_control end |
#component_count ⇒ Fixnum
Number of underlying components that make up this object. Components are
accumulated by compose operations.
Corresponds to the JSON property componentCount
2492 2493 2494 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2492 def component_count @component_count end |
#content_disposition ⇒ String
Content-Disposition of the object data.
Corresponds to the JSON property contentDisposition
2497 2498 2499 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2497 def content_disposition @content_disposition end |
#content_encoding ⇒ String
Content-Encoding of the object data.
Corresponds to the JSON property contentEncoding
2502 2503 2504 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2502 def content_encoding @content_encoding end |
#content_language ⇒ String
Content-Language of the object data.
Corresponds to the JSON property contentLanguage
2507 2508 2509 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2507 def content_language @content_language end |
#content_type ⇒ String
Content-Type of the object data. If an object is stored without a Content-Type,
it is served as application/octet-stream.
Corresponds to the JSON property contentType
2513 2514 2515 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2513 def content_type @content_type end |
#contexts ⇒ Google::Apis::StorageV1::Object::Contexts
User-defined or system-defined object contexts. Each object context is a key-
payload pair, where the key provides the identification and the payload holds
the associated value and additional metadata.
Corresponds to the JSON property contexts
2520 2521 2522 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2520 def contexts @contexts end |
#crc32c ⇒ String
CRC32c checksum, as described in RFC 4960, Appendix B; encoded using base64 in
big-endian byte order. For more information about using the CRC32c checksum,
see Data Validation and Change Detection.
Corresponds to the JSON property crc32c
2528 2529 2530 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2528 def crc32c @crc32c end |
#custom_time ⇒ DateTime
A timestamp in RFC 3339 format specified by the user for an object.
Corresponds to the JSON property customTime
2533 2534 2535 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2533 def custom_time @custom_time end |
#customer_encryption ⇒ Google::Apis::StorageV1::Object::CustomerEncryption
Metadata of customer-supplied encryption key, if the object is encrypted by
such a key.
Corresponds to the JSON property customerEncryption
2539 2540 2541 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2539 def customer_encryption @customer_encryption end |
#etag ⇒ String
HTTP 1.1 Entity tag for the object.
Corresponds to the JSON property etag
2544 2545 2546 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2544 def etag @etag end |
#event_based_hold ⇒ Boolean Also known as: event_based_hold?
Whether an object is under event-based hold. Event-based hold is a way to
retain objects until an event occurs, which is signified by the hold's release
(i.e. this value is set to false). After being released (set to false), such
objects will be subject to bucket-level retention (if any). One sample use
case of this flag is for banks to hold loan documents for at least 3 years
after loan is paid in full. Here, bucket-level retention is 3 years and the
event is the loan being paid in full. In this example, these objects will be
held intact for any number of years until the event has occurred (event-based
hold on the object is released) and then 3 more years after that. That means
retention duration of the objects begins from the moment event-based hold
transitioned from true to false.
Corresponds to the JSON property eventBasedHold
2559 2560 2561 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2559 def event_based_hold @event_based_hold end |
#generation ⇒ Fixnum
The content generation of this object. Used for object versioning.
Corresponds to the JSON property generation
2565 2566 2567 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2565 def generation @generation end |
#hard_delete_time ⇒ DateTime
This is the time (in the future) when the soft-deleted object will no longer
be restorable. It is equal to the soft delete time plus the current soft
delete retention duration of the bucket.
Corresponds to the JSON property hardDeleteTime
2572 2573 2574 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2572 def hard_delete_time @hard_delete_time end |
#id ⇒ String
The ID of the object, including the bucket name, object name, and generation
number.
Corresponds to the JSON property id
2578 2579 2580 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2578 def id @id end |
#kind ⇒ String
The kind of item this is. For objects, this is always storage#object.
Corresponds to the JSON property kind
2583 2584 2585 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2583 def kind @kind end |
#kms_key_name ⇒ String
Not currently supported. Specifying the parameter causes the request to fail
with status code 400 - Bad Request.
Corresponds to the JSON property kmsKeyName
2589 2590 2591 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2589 def kms_key_name @kms_key_name end |
#md5_hash ⇒ String
MD5 hash of the data; encoded using base64. For more information about using
the MD5 hash, see Data Validation and Change Detection.
Corresponds to the JSON property md5Hash
2596 2597 2598 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2596 def md5_hash @md5_hash end |
#media_link ⇒ String
Media download link.
Corresponds to the JSON property mediaLink
2601 2602 2603 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2601 def media_link @media_link end |
#metadata ⇒ Hash<String,String>
User-provided metadata, in key/value pairs.
Corresponds to the JSON property metadata
2606 2607 2608 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2606 def @metadata end |
#metageneration ⇒ Fixnum
The version of the metadata for this object at this generation. Used for
preconditions and for detecting changes in metadata. A metageneration number
is only meaningful in the context of a particular generation of a particular
object.
Corresponds to the JSON property metageneration
2614 2615 2616 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2614 def @metageneration end |
#name ⇒ String
The name of the object. Required if not specified by URL parameter.
Corresponds to the JSON property name
2619 2620 2621 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2619 def name @name end |
#owner ⇒ Google::Apis::StorageV1::Object::Owner
The owner of the object. This will always be the uploader of the object.
Corresponds to the JSON property owner
2624 2625 2626 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2624 def owner @owner end |
#restore_token ⇒ String
Restore token used to differentiate deleted objects with the same name and
generation. This field is only returned for deleted objects in hierarchical
namespace buckets.
Corresponds to the JSON property restoreToken
2631 2632 2633 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2631 def restore_token @restore_token end |
#retention ⇒ Google::Apis::StorageV1::Object::Retention
A collection of object level retention parameters.
Corresponds to the JSON property retention
2636 2637 2638 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2636 def retention @retention end |
#retention_expiration_time ⇒ DateTime
A server-determined value that specifies the earliest time that the object's
retention period expires. This value is in RFC 3339 format. Note 1: This field
is not provided for objects with an active event-based hold, since retention
expiration is unknown until the hold is removed. Note 2: This value can be
provided even when temporary hold is set (so that the user can reason about
policy without having to first unset the temporary hold).
Corresponds to the JSON property retentionExpirationTime
2646 2647 2648 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2646 def retention_expiration_time @retention_expiration_time end |
#self_link ⇒ String
The link to this object.
Corresponds to the JSON property selfLink
2651 2652 2653 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2651 def self_link @self_link end |
#size ⇒ Fixnum
Content-Length of the data in bytes.
Corresponds to the JSON property size
2656 2657 2658 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2656 def size @size end |
#soft_delete_time ⇒ DateTime
The time at which the object became soft-deleted in RFC 3339 format.
Corresponds to the JSON property softDeleteTime
2661 2662 2663 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2661 def soft_delete_time @soft_delete_time end |
#storage_class ⇒ String
Storage class of the object.
Corresponds to the JSON property storageClass
2666 2667 2668 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2666 def storage_class @storage_class end |
#temporary_hold ⇒ Boolean Also known as: temporary_hold?
Whether an object is under temporary hold. While this flag is set to true, the
object is protected against deletion and overwrites. A common use case of this
flag is regulatory investigations where objects need to be retained while the
investigation is ongoing. Note that unlike event-based hold, temporary hold
does not impact retention expiration time of an object.
Corresponds to the JSON property temporaryHold
2675 2676 2677 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2675 def temporary_hold @temporary_hold end |
#time_created ⇒ DateTime
The creation time of the object in RFC 3339 format.
Corresponds to the JSON property timeCreated
2681 2682 2683 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2681 def time_created @time_created end |
#time_deleted ⇒ DateTime
The time at which the object became noncurrent in RFC 3339 format. Will be
returned if and only if this version of the object has been deleted.
Corresponds to the JSON property timeDeleted
2687 2688 2689 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2687 def time_deleted @time_deleted end |
#time_finalized ⇒ DateTime
The time when the object was finalized.
Corresponds to the JSON property timeFinalized
2692 2693 2694 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2692 def time_finalized @time_finalized end |
#time_storage_class_updated ⇒ DateTime
The time at which the object's storage class was last changed. When the object
is initially created, it will be set to timeCreated.
Corresponds to the JSON property timeStorageClassUpdated
2698 2699 2700 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2698 def time_storage_class_updated @time_storage_class_updated end |
#updated ⇒ DateTime
The modification time of the object metadata in RFC 3339 format. Set initially
to object creation time and then updated whenever any metadata of the object
changes. This includes changes made by a requester, such as modifying custom
metadata, as well as changes made by Cloud Storage on behalf of a requester,
such as changing the storage class based on an Object Lifecycle Configuration.
Corresponds to the JSON property updated
2707 2708 2709 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2707 def updated @updated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 2753 |
# File 'lib/google/apis/storage_v1/classes.rb', line 2714 def update!(**args) @acl = args[:acl] if args.key?(:acl) @bucket = args[:bucket] if args.key?(:bucket) @cache_control = args[:cache_control] if args.key?(:cache_control) @component_count = args[:component_count] if args.key?(:component_count) @content_disposition = args[:content_disposition] if args.key?(:content_disposition) @content_encoding = args[:content_encoding] if args.key?(:content_encoding) @content_language = args[:content_language] if args.key?(:content_language) @content_type = args[:content_type] if args.key?(:content_type) @contexts = args[:contexts] if args.key?(:contexts) @crc32c = args[:crc32c] if args.key?(:crc32c) @custom_time = args[:custom_time] if args.key?(:custom_time) @customer_encryption = args[:customer_encryption] if args.key?(:customer_encryption) @etag = args[:etag] if args.key?(:etag) @event_based_hold = args[:event_based_hold] if args.key?(:event_based_hold) @generation = args[:generation] if args.key?(:generation) @hard_delete_time = args[:hard_delete_time] if args.key?(:hard_delete_time) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @md5_hash = args[:md5_hash] if args.key?(:md5_hash) @media_link = args[:media_link] if args.key?(:media_link) @metadata = args[:metadata] if args.key?(:metadata) @metageneration = args[:metageneration] if args.key?(:metageneration) @name = args[:name] if args.key?(:name) @owner = args[:owner] if args.key?(:owner) @restore_token = args[:restore_token] if args.key?(:restore_token) @retention = args[:retention] if args.key?(:retention) @retention_expiration_time = args[:retention_expiration_time] if args.key?(:retention_expiration_time) @self_link = args[:self_link] if args.key?(:self_link) @size = args[:size] if args.key?(:size) @soft_delete_time = args[:soft_delete_time] if args.key?(:soft_delete_time) @storage_class = args[:storage_class] if args.key?(:storage_class) @temporary_hold = args[:temporary_hold] if args.key?(:temporary_hold) @time_created = args[:time_created] if args.key?(:time_created) @time_deleted = args[:time_deleted] if args.key?(:time_deleted) @time_finalized = args[:time_finalized] if args.key?(:time_finalized) @time_storage_class_updated = args[:time_storage_class_updated] if args.key?(:time_storage_class_updated) @updated = args[:updated] if args.key?(:updated) end |