Class: Google::Apis::StorageV1::ObjectAccessControl

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

An access-control entry.

Defined Under Namespace

Classes: ProjectTeam

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ObjectAccessControl

Returns a new instance of ObjectAccessControl.



2916
2917
2918
# File 'lib/google/apis/storage_v1/classes.rb', line 2916

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucketString

The name of the bucket. Corresponds to the JSON property bucket

Returns:

  • (String)


2841
2842
2843
# File 'lib/google/apis/storage_v1/classes.rb', line 2841

def bucket
  @bucket
end

#domainString

The domain associated with the entity, if any. Corresponds to the JSON property domain

Returns:

  • (String)


2846
2847
2848
# File 'lib/google/apis/storage_v1/classes.rb', line 2846

def domain
  @domain
end

#emailString

The email address associated with the entity, if any. Corresponds to the JSON property email

Returns:

  • (String)


2851
2852
2853
# File 'lib/google/apis/storage_v1/classes.rb', line 2851

def email
  @email
end

#entityString

The entity holding the permission, in one of the following forms:

Returns:

  • (String)


2868
2869
2870
# File 'lib/google/apis/storage_v1/classes.rb', line 2868

def entity
  @entity
end

#entity_idString

The ID for the entity, if any. Corresponds to the JSON property entityId

Returns:

  • (String)


2873
2874
2875
# File 'lib/google/apis/storage_v1/classes.rb', line 2873

def entity_id
  @entity_id
end

#etagString

HTTP 1.1 Entity tag for the access-control entry. Corresponds to the JSON property etag

Returns:

  • (String)


2878
2879
2880
# File 'lib/google/apis/storage_v1/classes.rb', line 2878

def etag
  @etag
end

#generationFixnum

The content generation of the object, if applied to an object. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


2883
2884
2885
# File 'lib/google/apis/storage_v1/classes.rb', line 2883

def generation
  @generation
end

#idString

The ID of the access-control entry. Corresponds to the JSON property id

Returns:

  • (String)


2888
2889
2890
# File 'lib/google/apis/storage_v1/classes.rb', line 2888

def id
  @id
end

#kindString

The kind of item this is. For object access control entries, this is always storage#objectAccessControl. Corresponds to the JSON property kind

Returns:

  • (String)


2894
2895
2896
# File 'lib/google/apis/storage_v1/classes.rb', line 2894

def kind
  @kind
end

#objectString

The name of the object, if applied to an object. Corresponds to the JSON property object

Returns:

  • (String)


2899
2900
2901
# File 'lib/google/apis/storage_v1/classes.rb', line 2899

def object
  @object
end

#project_teamGoogle::Apis::StorageV1::ObjectAccessControl::ProjectTeam

The project team associated with the entity, if any. Corresponds to the JSON property projectTeam



2904
2905
2906
# File 'lib/google/apis/storage_v1/classes.rb', line 2904

def project_team
  @project_team
end

#roleString

The access permission for the entity. Corresponds to the JSON property role

Returns:

  • (String)


2909
2910
2911
# File 'lib/google/apis/storage_v1/classes.rb', line 2909

def role
  @role
end

The link to this access-control entry. Corresponds to the JSON property selfLink

Returns:

  • (String)


2914
2915
2916
# File 'lib/google/apis/storage_v1/classes.rb', line 2914

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
# File 'lib/google/apis/storage_v1/classes.rb', line 2921

def update!(**args)
  @bucket = args[:bucket] if args.key?(:bucket)
  @domain = args[:domain] if args.key?(:domain)
  @email = args[:email] if args.key?(:email)
  @entity = args[:entity] if args.key?(:entity)
  @entity_id = args[:entity_id] if args.key?(:entity_id)
  @etag = args[:etag] if args.key?(:etag)
  @generation = args[:generation] if args.key?(:generation)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @object = args[:object] if args.key?(:object)
  @project_team = args[:project_team] if args.key?(:project_team)
  @role = args[:role] if args.key?(:role)
  @self_link = args[:self_link] if args.key?(:self_link)
end