Class: Google::Apis::StorageV1::ObjectCustomContextPayload

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

The payload of a single user-defined object context.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ObjectCustomContextPayload

Returns a new instance of ObjectCustomContextPayload.



3008
3009
3010
# File 'lib/google/apis/storage_v1/classes.rb', line 3008

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeDateTime

The time at which the object context was created in RFC 3339 format. Corresponds to the JSON property createTime

Returns:

  • (DateTime)


2996
2997
2998
# File 'lib/google/apis/storage_v1/classes.rb', line 2996

def create_time
  @create_time
end

#update_timeDateTime

The time at which the object context was last updated in RFC 3339 format. Corresponds to the JSON property updateTime

Returns:

  • (DateTime)


3001
3002
3003
# File 'lib/google/apis/storage_v1/classes.rb', line 3001

def update_time
  @update_time
end

#valueString

The value of the object context. Corresponds to the JSON property value

Returns:

  • (String)


3006
3007
3008
# File 'lib/google/apis/storage_v1/classes.rb', line 3006

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3013
3014
3015
3016
3017
# File 'lib/google/apis/storage_v1/classes.rb', line 3013

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value = args[:value] if args.key?(:value)
end