Class: Google::Apis::StorageV1::RapidCache
- Inherits:
-
Object
- Object
- Google::Apis::StorageV1::RapidCache
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb
Overview
A Rapid Cache instance.
Instance Attribute Summary collapse
-
#admission_policy ⇒ String
The cache-level entry admission policy.
-
#bucket ⇒ String
The name of the bucket containing this cache instance.
-
#cache_type ⇒ String
The type of Rapid Cache this represents.
-
#create_time ⇒ DateTime
The creation time of the cache instance in RFC 3339 format.
-
#id ⇒ String
The ID of the resource, including the project number, bucket name and rapid cache ID.
-
#ingest_on_write ⇒ Boolean
(also: #ingest_on_write?)
Specifies whether objects are ingested into the cache upon write.
-
#kind ⇒ String
The kind of item this is.
-
#pending_update ⇒ Boolean
(also: #pending_update?)
True if the cache instance has an active Update long-running operation.
-
#rapid_cache_id ⇒ String
The ID of the Rapid cache instance.
-
#self_link ⇒ String
The link to this cache instance.
-
#state ⇒ String
The current state of the cache instance.
-
#ttl ⇒ String
The TTL of all cache entries in whole seconds.
-
#update_time ⇒ DateTime
The modification time of the cache instance metadata in RFC 3339 format.
-
#zone ⇒ String
The zone in which the cache instance is running.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RapidCache
constructor
A new instance of RapidCache.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RapidCache
Returns a new instance of RapidCache.
3288 3289 3290 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3288 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admission_policy ⇒ String
The cache-level entry admission policy.
Corresponds to the JSON property admissionPolicy
3217 3218 3219 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3217 def admission_policy @admission_policy end |
#bucket ⇒ String
The name of the bucket containing this cache instance.
Corresponds to the JSON property bucket
3222 3223 3224 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3222 def bucket @bucket end |
#cache_type ⇒ String
The type of Rapid Cache this represents. Valid values include: "rapid-cache"
and "rapid-cache-ultra".
Corresponds to the JSON property cacheType
3228 3229 3230 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3228 def cache_type @cache_type end |
#create_time ⇒ DateTime
The creation time of the cache instance in RFC 3339 format.
Corresponds to the JSON property createTime
3233 3234 3235 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3233 def create_time @create_time end |
#id ⇒ String
The ID of the resource, including the project number, bucket name and rapid
cache ID.
Corresponds to the JSON property id
3239 3240 3241 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3239 def id @id end |
#ingest_on_write ⇒ Boolean Also known as: ingest_on_write?
Specifies whether objects are ingested into the cache upon write.
Corresponds to the JSON property ingestOnWrite
3244 3245 3246 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3244 def ingest_on_write @ingest_on_write end |
#kind ⇒ String
The kind of item this is. For Rapid Cache, this is always storage#rapidCache.
Corresponds to the JSON property kind
3250 3251 3252 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3250 def kind @kind end |
#pending_update ⇒ Boolean Also known as: pending_update?
True if the cache instance has an active Update long-running operation.
Corresponds to the JSON property pendingUpdate
3255 3256 3257 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3255 def pending_update @pending_update end |
#rapid_cache_id ⇒ String
The ID of the Rapid cache instance.
Corresponds to the JSON property rapidCacheId
3261 3262 3263 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3261 def rapid_cache_id @rapid_cache_id end |
#self_link ⇒ String
The link to this cache instance.
Corresponds to the JSON property selfLink
3266 3267 3268 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3266 def self_link @self_link end |
#state ⇒ String
The current state of the cache instance.
Corresponds to the JSON property state
3271 3272 3273 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3271 def state @state end |
#ttl ⇒ String
The TTL of all cache entries in whole seconds. e.g., "7200s".
Corresponds to the JSON property ttl
3276 3277 3278 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3276 def ttl @ttl end |
#update_time ⇒ DateTime
The modification time of the cache instance metadata in RFC 3339 format.
Corresponds to the JSON property updateTime
3281 3282 3283 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3281 def update_time @update_time end |
#zone ⇒ String
The zone in which the cache instance is running. For example, us-central1-a.
Corresponds to the JSON property zone
3286 3287 3288 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3286 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 3308 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3293 def update!(**args) @admission_policy = args[:admission_policy] if args.key?(:admission_policy) @bucket = args[:bucket] if args.key?(:bucket) @cache_type = args[:cache_type] if args.key?(:cache_type) @create_time = args[:create_time] if args.key?(:create_time) @id = args[:id] if args.key?(:id) @ingest_on_write = args[:ingest_on_write] if args.key?(:ingest_on_write) @kind = args[:kind] if args.key?(:kind) @pending_update = args[:pending_update] if args.key?(:pending_update) @rapid_cache_id = args[:rapid_cache_id] if args.key?(:rapid_cache_id) @self_link = args[:self_link] if args.key?(:self_link) @state = args[:state] if args.key?(:state) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) @zone = args[:zone] if args.key?(:zone) end |