Class: Google::Apis::StorageV1::RapidCachePolicy
- Inherits:
-
Object
- Object
- Google::Apis::StorageV1::RapidCachePolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb
Overview
The rapid cache policy configuration for a managed folder.
Instance Attribute Summary collapse
-
#ingest_on_write ⇒ String
The ingest-on-write policy for objects in the managed folder.
-
#rapid_cache_id ⇒ String
The unique identifier of the rapid cache.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RapidCachePolicy
constructor
A new instance of RapidCachePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RapidCachePolicy
Returns a new instance of RapidCachePolicy.
3347 3348 3349 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3347 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ingest_on_write ⇒ String
The ingest-on-write policy for objects in the managed folder. When set to
enabled, objects are automatically ingested into the cache when they are
written to the managed folder.
Corresponds to the JSON property ingestOnWrite
3340 3341 3342 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3340 def ingest_on_write @ingest_on_write end |
#rapid_cache_id ⇒ String
The unique identifier of the rapid cache.
Corresponds to the JSON property rapidCacheId
3345 3346 3347 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3345 def rapid_cache_id @rapid_cache_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3352 3353 3354 3355 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3352 def update!(**args) @ingest_on_write = args[:ingest_on_write] if args.key?(:ingest_on_write) @rapid_cache_id = args[:rapid_cache_id] if args.key?(:rapid_cache_id) end |