Class: Google::Apis::StorageV1::RelocateBucketRequest
- Inherits:
-
Object
- Object
- Google::Apis::StorageV1::RelocateBucketRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb
Overview
A Relocate Bucket request.
Defined Under Namespace
Classes: DestinationCustomPlacementConfig
Instance Attribute Summary collapse
-
#destination_custom_placement_config ⇒ Google::Apis::StorageV1::RelocateBucketRequest::DestinationCustomPlacementConfig
The bucket's new custom placement configuration if relocating to a Custom Dual Region.
-
#destination_kms_key_name ⇒ String
Resource name of a Cloud KMS key, of the form projects/my-project/locations/ global/keyRings/my-kr/cryptoKeys/my-key.
-
#destination_location ⇒ String
The new location the bucket will be relocated to.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, validate the operation, but do not actually relocate the bucket.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RelocateBucketRequest
constructor
A new instance of RelocateBucketRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RelocateBucketRequest
Returns a new instance of RelocateBucketRequest.
3213 3214 3215 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3213 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination_custom_placement_config ⇒ Google::Apis::StorageV1::RelocateBucketRequest::DestinationCustomPlacementConfig
The bucket's new custom placement configuration if relocating to a Custom Dual
Region.
Corresponds to the JSON property destinationCustomPlacementConfig
3193 3194 3195 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3193 def destination_custom_placement_config @destination_custom_placement_config end |
#destination_kms_key_name ⇒ String
Resource name of a Cloud KMS key, of the form projects/my-project/locations/
global/keyRings/my-kr/cryptoKeys/my-key. If set, is used to encrypt all
objects in the destination bucket.
Corresponds to the JSON property destinationKmsKeyName
3200 3201 3202 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3200 def destination_kms_key_name @destination_kms_key_name end |
#destination_location ⇒ String
The new location the bucket will be relocated to.
Corresponds to the JSON property destinationLocation
3205 3206 3207 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3205 def destination_location @destination_location end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, validate the operation, but do not actually relocate the bucket.
Corresponds to the JSON property validateOnly
3210 3211 3212 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3210 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3218 3219 3220 3221 3222 3223 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3218 def update!(**args) @destination_custom_placement_config = args[:destination_custom_placement_config] if args.key?(:destination_custom_placement_config) @destination_kms_key_name = args[:destination_kms_key_name] if args.key?(:destination_kms_key_name) @destination_location = args[:destination_location] if args.key?(:destination_location) @validate_only = args[:validate_only] if args.key?(:validate_only) end |