Class: Google::Apis::StorageV1::RewriteResponse
- Inherits:
-
Object
- Object
- Google::Apis::StorageV1::RewriteResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb
Overview
A rewrite response.
Instance Attribute Summary collapse
-
#done ⇒ Boolean
(also: #done?)
true if the copy is finished; otherwise, false if the copy is in progress.
-
#kind ⇒ String
The kind of item this is.
-
#object_size ⇒ Fixnum
The total size of the object being copied in bytes.
-
#resource ⇒ Google::Apis::StorageV1::Object
An object.
-
#rewrite_token ⇒ String
A token to use in subsequent requests to continue copying data.
-
#total_bytes_rewritten ⇒ Fixnum
The total bytes written so far, which can be used to provide a waiting user with a progress indicator.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RewriteResponse
constructor
A new instance of RewriteResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RewriteResponse
Returns a new instance of RewriteResponse.
3292 3293 3294 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3292 def initialize(**args) update!(**args) end |
Instance Attribute Details
#done ⇒ Boolean Also known as: done?
true if the copy is finished; otherwise, false if the copy is in progress.
This property is always present in the response.
Corresponds to the JSON property done
3261 3262 3263 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3261 def done @done end |
#kind ⇒ String
The kind of item this is.
Corresponds to the JSON property kind
3267 3268 3269 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3267 def kind @kind end |
#object_size ⇒ Fixnum
The total size of the object being copied in bytes. This property is always
present in the response.
Corresponds to the JSON property objectSize
3273 3274 3275 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3273 def object_size @object_size end |
#resource ⇒ Google::Apis::StorageV1::Object
An object.
Corresponds to the JSON property resource
3278 3279 3280 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3278 def resource @resource end |
#rewrite_token ⇒ String
A token to use in subsequent requests to continue copying data. This token is
present in the response only when there is more data to copy.
Corresponds to the JSON property rewriteToken
3284 3285 3286 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3284 def rewrite_token @rewrite_token end |
#total_bytes_rewritten ⇒ Fixnum
The total bytes written so far, which can be used to provide a waiting user
with a progress indicator. This property is always present in the response.
Corresponds to the JSON property totalBytesRewritten
3290 3291 3292 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3290 def total_bytes_rewritten @total_bytes_rewritten end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3297 3298 3299 3300 3301 3302 3303 3304 |
# File 'lib/google/apis/storage_v1/classes.rb', line 3297 def update!(**args) @done = args[:done] if args.key?(:done) @kind = args[:kind] if args.key?(:kind) @object_size = args[:object_size] if args.key?(:object_size) @resource = args[:resource] if args.key?(:resource) @rewrite_token = args[:rewrite_token] if args.key?(:rewrite_token) @total_bytes_rewritten = args[:total_bytes_rewritten] if args.key?(:total_bytes_rewritten) end |