Class: Google::Apis::StorageV1::RewriteResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storage_v1/classes.rb,
lib/google/apis/storage_v1/representations.rb,
lib/google/apis/storage_v1/representations.rb

Overview

A rewrite response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RewriteResponse

Returns a new instance of RewriteResponse.



3285
3286
3287
# File 'lib/google/apis/storage_v1/classes.rb', line 3285

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#doneBoolean Also known as: done?

true if the copy is finished; otherwise, false if the copy is in progress. This property is always present in the response. Corresponds to the JSON property done

Returns:

  • (Boolean)


3254
3255
3256
# File 'lib/google/apis/storage_v1/classes.rb', line 3254

def done
  @done
end

#kindString

The kind of item this is. Corresponds to the JSON property kind

Returns:

  • (String)


3260
3261
3262
# File 'lib/google/apis/storage_v1/classes.rb', line 3260

def kind
  @kind
end

#object_sizeFixnum

The total size of the object being copied in bytes. This property is always present in the response. Corresponds to the JSON property objectSize

Returns:

  • (Fixnum)


3266
3267
3268
# File 'lib/google/apis/storage_v1/classes.rb', line 3266

def object_size
  @object_size
end

#resourceGoogle::Apis::StorageV1::Object

An object. Corresponds to the JSON property resource



3271
3272
3273
# File 'lib/google/apis/storage_v1/classes.rb', line 3271

def resource
  @resource
end

#rewrite_tokenString

A token to use in subsequent requests to continue copying data. This token is present in the response only when there is more data to copy. Corresponds to the JSON property rewriteToken

Returns:

  • (String)


3277
3278
3279
# File 'lib/google/apis/storage_v1/classes.rb', line 3277

def rewrite_token
  @rewrite_token
end

#total_bytes_rewrittenFixnum

The total bytes written so far, which can be used to provide a waiting user with a progress indicator. This property is always present in the response. Corresponds to the JSON property totalBytesRewritten

Returns:

  • (Fixnum)


3283
3284
3285
# File 'lib/google/apis/storage_v1/classes.rb', line 3283

def total_bytes_rewritten
  @total_bytes_rewritten
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3290
3291
3292
3293
3294
3295
3296
3297
# File 'lib/google/apis/storage_v1/classes.rb', line 3290

def update!(**args)
  @done = args[:done] if args.key?(:done)
  @kind = args[:kind] if args.key?(:kind)
  @object_size = args[:object_size] if args.key?(:object_size)
  @resource = args[:resource] if args.key?(:resource)
  @rewrite_token = args[:rewrite_token] if args.key?(:rewrite_token)
  @total_bytes_rewritten = args[:total_bytes_rewritten] if args.key?(:total_bytes_rewritten)
end